@@ -104,17 +104,13 @@ Output::Rotation toKScreenRotation(int32_t transform)
     case WL_OUTPUT_TRANSFORM_270:
         return Output::Right;
     case WL_OUTPUT_TRANSFORM_FLIPPED:
-        qCWarning(KSCREEN_WAYLAND) << "flipped transform is unsupported by kscreen";
-        return Output::None;
+        return Output::Flipped;
     case WL_OUTPUT_TRANSFORM_FLIPPED_90:
-        qCWarning(KSCREEN_WAYLAND) << "flipped-90 transform is unsupported by kscreen";
-        return Output::Left;
+        return Output::Flipped90;
     case WL_OUTPUT_TRANSFORM_FLIPPED_180:
-        qCWarning(KSCREEN_WAYLAND) << "flipped-180 transform is unsupported by kscreen";
-        return Output::Inverted;
+        return Output::Flipped180;
     case WL_OUTPUT_TRANSFORM_FLIPPED_270:
-        qCWarning(KSCREEN_WAYLAND) << "flipped-270 transform is unsupported by kscreen";
-        return Output::Right;
+        return Output::Flipped270;
     default:
         Q_UNREACHABLE();
     }
@@ -131,6 +127,14 @@ wl_output_transform toKWaylandTransform(const Output::Rotation rotation)
         return WL_OUTPUT_TRANSFORM_180;
     case Output::Right:
         return WL_OUTPUT_TRANSFORM_270;
+    case Output::Flipped:
+        return WL_OUTPUT_TRANSFORM_FLIPPED;
+    case Output::Flipped90:
+        return WL_OUTPUT_TRANSFORM_FLIPPED_90;
+    case Output::Flipped180:
+        return WL_OUTPUT_TRANSFORM_FLIPPED_180;
+    case Output::Flipped270:
+        return WL_OUTPUT_TRANSFORM_FLIPPED_270;
     default:
         Q_UNREACHABLE();
     }
@@ -192,6 +196,11 @@ void WaylandOutputDevice::updateKScreenOutput(OutputPtr &output)
     output->setOverscan(m_overscan);
     output->setVrrPolicy(static_cast<Output::VrrPolicy>(m_vrr_policy));
     output->setRgbRange(static_cast<Output::RgbRange>(m_rgbRange));
+    output->setHdrEnabled(m_hdrEnabled);
+    output->setSdrBrightness(m_sdrBrightness);
+    output->setWcgEnabled(m_wideColorGamutEnabled);
+    output->setAutoRotatePolicy(static_cast<Output::AutoRotatePolicy>(m_autoRotatePolicy));
+    output->setIccProfilePath(m_iccProfilePath);
 
     updateKScreenModes(output);
 }
@@ -268,6 +277,26 @@ bool WaylandOutputDevice::setWlConfig(WaylandOutputConfiguration *wlConfig, cons
     if (kde_output_configuration_v2_get_version(wlConfig->object()) >= KDE_OUTPUT_CONFIGURATION_V2_SET_PRIORITY_SINCE_VERSION) {
         wlConfig->set_priority(object(), output->priority());
     }
+    if ((output->capabilities() & Output::Capability::HighDynamicRange) && (m_hdrEnabled == 1) != output->isHdrEnabled()) {
+        wlConfig->set_high_dynamic_range(object(), output->isHdrEnabled());
+        changed = true;
+    }
+    if ((output->capabilities() & Output::Capability::HighDynamicRange) && m_sdrBrightness != output->sdrBrightness()) {
+        wlConfig->set_sdr_brightness(object(), output->sdrBrightness());
+        changed = true;
+    }
+    if ((output->capabilities() & Output::Capability::WideColorGamut) && (m_wideColorGamutEnabled == 1) != output->isWcgEnabled()) {
+        wlConfig->set_wide_color_gamut(object(), output->isWcgEnabled());
+        changed = true;
+    }
+    if ((output->capabilities() & Output::Capability::AutoRotation) && m_autoRotatePolicy != static_cast<uint32_t>(output->autoRotatePolicy())) {
+        wlConfig->set_auto_rotate_policy(object(), static_cast<uint32_t>(output->autoRotatePolicy()));
+        changed = true;
+    }
+    if ((output->capabilities() & Output::Capability::IccProfile) && m_iccProfilePath != output->iccProfilePath()) {
+        wlConfig->set_icc_profile_path(object(), output->iccProfilePath());
+        changed = true;
+    }
 
     return changed;
 }
@@ -364,6 +393,31 @@ void WaylandOutputDevice::kde_output_device_v2_name(const QString &outputName)
     m_outputName = outputName;
 }
 
+void WaylandOutputDevice::kde_output_device_v2_high_dynamic_range(uint32_t hdr_enabled)
+{
+    m_hdrEnabled = hdr_enabled == 1;
+}
+
+void WaylandOutputDevice::kde_output_device_v2_sdr_brightness(uint32_t sdr_brightness)
+{
+    m_sdrBrightness = sdr_brightness;
+}
+
+void WaylandOutputDevice::kde_output_device_v2_wide_color_gamut(uint32_t wcg_enabled)
+{
+    m_wideColorGamutEnabled = wcg_enabled == 1;
+}
+
+void WaylandOutputDevice::kde_output_device_v2_auto_rotate_policy(uint32_t policy)
+{
+    m_autoRotatePolicy = policy;
+}
+
+void WaylandOutputDevice::kde_output_device_v2_icc_profile_path(const QString &profile)
+{
+    m_iccProfilePath = profile;
+}
+
 QByteArray WaylandOutputDevice::edid() const
 {
     return m_edid;
@@ -428,3 +482,5 @@ uint32_t WaylandOutputDevice::rgbRange() const
 {
     return m_rgbRange;
 }
+
+#include "moc_waylandoutputdevice.cpp"
