@@ -4,8 +4,7 @@
  *
  *  SPDX-License-Identifier: LGPL-2.1-or-later
  */
-#ifndef WAYLANDOUTPUTDEVICE_H
-#define WAYLANDOUTPUTDEVICE_H
+#pragma once
 
 #include "waylandoutputdevicemode.h"
 
@@ -87,6 +86,11 @@ protected:
     void kde_output_device_v2_vrr_policy(uint32_t vrr_policy) override;
     void kde_output_device_v2_rgb_range(uint32_t rgb_range) override;
     void kde_output_device_v2_name(const QString &name) override;
+    void kde_output_device_v2_high_dynamic_range(uint32_t hdr_enabled) override;
+    void kde_output_device_v2_sdr_brightness(uint32_t sdr_brightness) override;
+    void kde_output_device_v2_wide_color_gamut(uint32_t wcg_enabled) override;
+    void kde_output_device_v2_auto_rotate_policy(uint32_t policy) override;
+    void kde_output_device_v2_icc_profile_path(const QString &profile) override;
 
 private:
     QString modeName(const WaylandOutputDeviceMode *m) const;
@@ -114,10 +118,13 @@ private:
     uint32_t m_vrr_policy;
     uint32_t m_rgbRange;
     uint32_t m_index;
+    bool m_hdrEnabled = false;
+    uint32_t m_sdrBrightness = 200;
+    bool m_wideColorGamutEnabled = false;
+    uint32_t m_autoRotatePolicy = 1;
+    QString m_iccProfilePath;
 };
 
 }
 
 KSCREEN_EXPORT QDebug operator<<(QDebug dbg, const KScreen::WaylandOutputDevice *output);
-
-#endif // WAYLANDOUTPUTDEVICE_H
