@@ -276,7 +276,11 @@ void Doctor::parseOutputArgs()
                                                                                  {QStringLiteral("normal"), KScreen::Output::None},
                                                                                  {QStringLiteral("left"), KScreen::Output::Left},
                                                                                  {QStringLiteral("right"), KScreen::Output::Right},
-                                                                                 {QStringLiteral("inverted"), KScreen::Output::Inverted}});
+                                                                                 {QStringLiteral("inverted"), KScreen::Output::Inverted},
+                                                                                 {QStringLiteral("flipped"), KScreen::Output::Flipped},
+                                                                                 {QStringLiteral("flipped90"), KScreen::Output::Flipped90},
+                                                                                 {QStringLiteral("flipped180"), KScreen::Output::Flipped180},
+                                                                                 {QStringLiteral("flipped270"), KScreen::Output::Flipped270}});
                     KScreen::Output::Rotation rot = KScreen::Output::None;
                     // set orientation
                     if (rotationMap.contains(_rotation)) {
@@ -327,6 +331,43 @@ void Doctor::parseOutputArgs()
                         return;
                     }
                     setRgbRange(output, range);
+                } else if (ops.count() == 4 && subcmd == "hdr") {
+                    const QString _enable = ops[3].toLower();
+                    if (_enable == "enable") {
+                        setHdrEnabled(output, true);
+                    } else if (_enable == "disable") {
+                        setHdrEnabled(output, false);
+                    } else {
+                        qCDebug(KSCREEN_DOCTOR) << "Wrong input: Only allowed values for hdr are \"enable\" and \"disable\"";
+                        qApp->exit(9);
+                        return;
+                    }
+                } else if (ops.count() == 4 && subcmd == "sdr-brightness") {
+                    const uint32_t brightness = ops[3].toInt();
+                    if (brightness < 100 || brightness > 10000) {
+                        qCDebug(KSCREEN_DOCTOR) << "Wrong input: Allowed range for sdr-brightness is 100 to 10000";
+                        qApp->exit(9);
+                        return;
+                    }
+                    setSdrBrightness(output, brightness);
+                } else if (ops.count() == 4 && subcmd == "wcg") {
+                    const QString _enable = ops[3].toLower();
+                    if (_enable == "enable") {
+                        setWcgEnabled(output, true);
+                    } else if (_enable == "disable") {
+                        setWcgEnabled(output, false);
+                    } else {
+                        qCDebug(KSCREEN_DOCTOR) << "Wrong input: Only allowed values for wcg are \"enable\" and \"disable\"";
+                        qApp->exit(9);
+                        return;
+                    }
+                } else if (ops.count() >= 4 && subcmd == "iccprofile") {
+                    QString profilePath = ops[3];
+                    for (uint32_t i = 4; i < ops.size(); i++) {
+                        profilePath += "." + ops[i];
+                    }
+                    output->setIccProfilePath(profilePath);
+                    m_changed = true;
                 } else {
                     cerr << "Unable to parse arguments: " << op << Qt::endl;
                     qApp->exit(2);
@@ -446,6 +487,37 @@ void Doctor::showOutputs() const
         } else {
             cout << cr << "unknown";
         }
+        cout << yellow << " HDR: ";
+        if (output->capabilities() & Output::Capability::HighDynamicRange) {
+            if (output->isHdrEnabled()) {
+                cout << cr << "enabled";
+            } else {
+                cout << cr << "disabled";
+            }
+            cout << yellow << " SDR brightness: " << cr << output->sdrBrightness() << " nits";
+        } else {
+            cout << cr << "incapable";
+        }
+        cout << yellow << " Wide Color Gamut: ";
+        if (output->capabilities() & Output::Capability::WideColorGamut) {
+            if (output->isWcgEnabled()) {
+                cout << cr << "enabled";
+            } else {
+                cout << cr << "disabled";
+            }
+        } else {
+            cout << cr << "incapable";
+        }
+        cout << yellow << " ICC profile: ";
+        if (output->capabilities() & Output::Capability::IccProfile) {
+            if (output->iccProfilePath().isEmpty()) {
+                cout << cr << output->iccProfilePath();
+            } else {
+                cout << cr << "none";
+            }
+        } else {
+            cout << cr << "incapable";
+        }
         cout << cr << Qt::endl;
     }
 }
@@ -537,6 +609,24 @@ void KScreen::Doctor::setPriority(OutputPtr output, uint32_t priority)
     m_changed = true;
 }
 
+void Doctor::setHdrEnabled(OutputPtr output, bool enable)
+{
+    output->setHdrEnabled(enable);
+    m_changed = true;
+}
+
+void Doctor::setSdrBrightness(OutputPtr output, uint32_t brightness)
+{
+    output->setSdrBrightness(brightness);
+    m_changed = true;
+}
+
+void Doctor::setWcgEnabled(OutputPtr output, bool enable)
+{
+    output->setWcgEnabled(enable);
+    m_changed = true;
+}
+
 void Doctor::applyConfig()
 {
     if (!m_changed) {
@@ -547,3 +637,5 @@ void Doctor::applyConfig()
     qCDebug(KSCREEN_DOCTOR) << "setop exec returned" << m_config;
     qApp->exit(0);
 }
+
+#include "moc_doctor.cpp"
