@@ -27,14 +27,14 @@ public:
     Private()
         : id(0)
         , type(Unknown)
-        , replicationSource(0)
         , rotation(None)
-        , scale(1.0)
-        , explicitLogicalSize(QSizeF())
         , connected(false)
         , enabled(false)
         , priority(0)
+        , replicationSource(0)
         , edid(nullptr)
+        , scale(1.0)
+        , explicitLogicalSize(QSizeF())
     {
     }
 
@@ -62,6 +62,11 @@ public:
         , overscan(other.overscan)
         , vrrPolicy(other.vrrPolicy)
         , rgbRange(other.rgbRange)
+        , highDynamicRange(other.highDynamicRange)
+        , sdrBrightness(other.sdrBrightness)
+        , wideColorGamut(other.wideColorGamut)
+        , autoRotatePolicy(other.autoRotatePolicy)
+        , iccProfilePath(other.iccProfilePath)
     {
         const auto otherModeList = other.modeList;
         for (const ModePtr &otherMode : otherModeList) {
@@ -103,6 +108,11 @@ public:
     uint32_t overscan = 0;
     VrrPolicy vrrPolicy = VrrPolicy::Automatic;
     RgbRange rgbRange = RgbRange::Automatic;
+    bool highDynamicRange = false;
+    uint32_t sdrBrightness = 200;
+    bool wideColorGamut = false;
+    AutoRotatePolicy autoRotatePolicy = AutoRotatePolicy::InTabletMode;
+    QString iccProfilePath;
 };
 
 bool Output::Private::compareModeList(const ModeList &before, const ModeList &after)
@@ -664,6 +674,71 @@ void Output::setRgbRange(Output::RgbRange rgbRange)
     Q_EMIT rgbRangeChanged();
 }
 
+bool Output::isHdrEnabled() const
+{
+    return d->highDynamicRange;
+}
+
+void Output::setHdrEnabled(bool enable)
+{
+    if (d->highDynamicRange != enable) {
+        d->highDynamicRange = enable;
+        Q_EMIT hdrEnabledChanged();
+    }
+}
+
+uint32_t Output::sdrBrightness() const
+{
+    return d->sdrBrightness;
+}
+
+void Output::setSdrBrightness(uint32_t brightness)
+{
+    if (d->sdrBrightness != brightness) {
+        d->sdrBrightness = brightness;
+        Q_EMIT sdrBrightnessChanged();
+    }
+}
+
+bool Output::isWcgEnabled() const
+{
+    return d->wideColorGamut;
+}
+
+void Output::setWcgEnabled(bool enable)
+{
+    if (d->wideColorGamut != enable) {
+        d->wideColorGamut = enable;
+        Q_EMIT wcgEnabledChanged();
+    }
+}
+
+Output::AutoRotatePolicy Output::autoRotatePolicy() const
+{
+    return d->autoRotatePolicy;
+}
+
+void Output::setAutoRotatePolicy(AutoRotatePolicy policy)
+{
+    if (d->autoRotatePolicy != policy) {
+        d->autoRotatePolicy = policy;
+        Q_EMIT autoRotatePolicyChanged();
+    }
+}
+
+QString Output::iccProfilePath() const
+{
+    return d->iccProfilePath;
+}
+
+void Output::setIccProfilePath(const QString &path)
+{
+    if (d->iccProfilePath != path) {
+        d->iccProfilePath = path;
+        Q_EMIT iccProfilePathChanged();
+    }
+}
+
 void Output::apply(const OutputPtr &other)
 {
     typedef void (KScreen::Output::*ChangeSignal)();
@@ -749,6 +824,26 @@ void Output::apply(const OutputPtr &other)
         changes << &Output::rgbRangeChanged;
         setRgbRange(other->d->rgbRange);
     }
+    if (d->highDynamicRange != other->d->highDynamicRange) {
+        changes << &Output::hdrEnabledChanged;
+        setHdrEnabled(other->d->highDynamicRange);
+    }
+    if (d->sdrBrightness != other->d->sdrBrightness) {
+        changes << &Output::sdrBrightnessChanged;
+        setSdrBrightness(other->d->sdrBrightness);
+    }
+    if (d->wideColorGamut != other->d->wideColorGamut) {
+        changes << &Output::wcgEnabledChanged;
+        setWcgEnabled(other->d->wideColorGamut);
+    }
+    if (d->autoRotatePolicy != other->d->autoRotatePolicy) {
+        changes << &Output::autoRotatePolicyChanged;
+        setAutoRotatePolicy(other->d->autoRotatePolicy);
+    }
+    if (d->iccProfilePath != other->d->iccProfilePath) {
+        changes << &Output::iccProfilePathChanged;
+        setIccProfilePath(other->d->iccProfilePath);
+    }
 
     // Non-notifyable changes
     if (other->d->edid) {
@@ -791,3 +886,5 @@ QDebug operator<<(QDebug dbg, const KScreen::OutputPtr &output)
     // clang-format on
     return dbg;
 }
+
+#include "moc_output.cpp"
